@@ -78,6 +78,10 @@ class ClickReviewAccounts(ClickReview):
                               'account-provider',
                               'account-qml-plugin',
                               'account-service']
+
+        if self.manifest is None:
+            return
+
         for app in self.manifest['hooks']:
             for h in self.account_hooks:
                 if h not in self.manifest['hooks'][app]:
@@ -108,7 +112,6 @@ class ClickReviewAccounts(ClickReview):
             ('description', str),
         ]
         self.required_keys["plugin"] = [
-            ('provider', str),
             ('name', str),
             ('icon', str),
             ('qml', str),
@@ -120,6 +123,9 @@ class ClickReviewAccounts(ClickReview):
 
     def _extract_account(self, app, account_type):
         '''Extract accounts'''
+        if self.manifest is None:
+            return
+
         a = self.manifest['hooks'][app][account_type]
         fn = os.path.join(self.unpack_dir, a)
 
@@ -158,21 +164,24 @@ class ClickReviewAccounts(ClickReview):
 
     def check_hooks_versions(self):
         '''Check hooks versions'''
+        if self.manifest is None:
+            return
+
         framework = self.manifest['framework']
         if not framework.startswith("ubuntu-sdk"):
             return
         t = "error"
-        if framework < "ubuntu-sdk-15.10":
+        if framework < "ubuntu-sdk-15.04.1":
             for app in sorted(self.accounts.keys()):
                 for hook in self.accounts[app].keys():
                     if hook == "accounts":
                         n = self._get_check_name('%s_hook' % hook, app=app)
-                        s = "'accounts' hook is not available in '%s' (must be 15.10 or later)" % \
+                        s = "'accounts' hook is not available in '%s' (must be 15.04.1 or later)" % \
                             (framework)
                         self._add_result(t, n, s)
             return
         hook_state = "disallowed"
-        if framework < "ubuntu-sdk-16.04":
+        if framework < "ubuntu-sdk-16.10":
             t = "warn"
             hook_state = "deprecated"
         for app in sorted(self.accounts.keys()):
@@ -249,19 +258,23 @@ class ClickReviewAccounts(ClickReview):
                 self._add_result(t, n, s)
                 continue
 
+            has_services_or_plugin = False
             n = self._get_check_name('%s_services' % account_type, app=app)
-            if 'services' not in self.accounts[app][account_type]:
-                t = "error"
-                s = "'services' key is missing"
-                self._add_result(t, n, s)
-                continue
-            services = self.accounts[app][account_type]['services']
-            self._check_object_list(app, "services", "service", services)
+            if 'services' in self.accounts[app][account_type]:
+                has_services_or_plugin = True
+                services = self.accounts[app][account_type]['services']
+                self._check_object_list(app, "services", "service", services)
 
-            n = self._get_check_name('%s_plugins' % account_type, app=app)
-            if 'plugins' in self.accounts[app][account_type]:
-                plugins = self.accounts[app][account_type]['plugins']
-                self._check_object_list(app, "plugins", "plugin", plugins)
+            n = self._get_check_name('%s_plugin' % account_type, app=app)
+            if 'plugin' in self.accounts[app][account_type]:
+                has_services_or_plugin = True
+                plugin = self.accounts[app][account_type]['plugin']
+                self._check_object("plugin", plugin, n)
+
+            if not has_services_or_plugin:
+                t = "error"
+                s = "either 'services' or 'plugin' key must be present"
+                self._add_result(t, n, s)
 
     def check_application(self):
         '''Check application'''
@@ -340,6 +353,7 @@ class ClickReviewAccounts(ClickReview):
             if t == 'error':
                 continue
 
+            l = 'http://askubuntu.com/q/697173'
             for tag in ['name', 'provider']:
                 t = 'info'
                 n = self._get_check_name(
@@ -348,7 +362,7 @@ class ClickReviewAccounts(ClickReview):
                 if self.accounts[app][account_type].find(tag) is None:
                     t = 'error'
                     s = "Could not find '<%s>' tag" % tag
-                self._add_result(t, n, s)
+                self._add_result(t, n, s, l)
 
     def check_provider(self):
         '''Check provider'''
