@@ -40,6 +40,10 @@ class ClickReviewUrlDispatcher(ClickReview):
 
         self.url_dispatcher_files = dict()  # click-show-files and tests
         self.url_dispatcher = dict()
+
+        if self.manifest is None:
+            return
+
         for app in self.manifest['hooks']:
             if 'urls' not in self.manifest['hooks'][app]:
                 # msg("Skipped missing urls hook for '%s'" % app)
@@ -53,7 +57,11 @@ class ClickReviewUrlDispatcher(ClickReview):
     def _extract_url_dispatcher(self, app):
         '''Get url dispatcher json'''
         u = self.manifest['hooks'][app]['urls']
+        if not u:
+            error("'urls' definition is empty for '%s'" % app)
         fn = os.path.join(self.unpack_dir, u)
+        if not os.path.isfile(fn):
+            error("'%s' is not a file" % fn)
 
         bn = os.path.basename(fn)
         if not os.path.exists(fn):
