@@ -20,11 +20,6 @@ import clickreviews.cr_tests as cr_tests
 
 class TestClickReviewContentHub(cr_tests.TestClickReview):
     """Tests for the lint review tool."""
-    def setUp(self):
-        # Monkey patch various file access classes. stop() is handled with
-        # addCleanup in super()
-        cr_tests.mock_patch()
-        super()
 
     def test_check_unknown_keys_none(self):
         '''Test check_unknown() - no unknown'''
@@ -160,3 +155,28 @@ class TestClickReviewContentHub(cr_tests.TestClickReview):
         r = c.click_report
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
+
+    def test_check_valid_snappy_1504(self):
+        '''Test check_valid() - snappy 15.04'''
+        self.set_test_pkgfmt("snap", "15.04")
+        self.set_test_content_hub(self.default_appname, "destination", "pictures")
+        self.set_test_content_hub(self.default_appname, "share", "pictures")
+        self.set_test_content_hub(self.default_appname, "source", "pictures")
+        c = ClickReviewContentHub(self.test_name)
+        c.check_valid()
+        r = c.click_report
+        expected_counts = {'info': 6, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_valid_snappy_1604(self):
+        '''Test check_valid() - snappy 16.04'''
+        self.set_test_pkgfmt("snap", "16.04")
+        self.set_test_content_hub(self.default_appname, "destination", "pictures")
+        self.set_test_content_hub(self.default_appname, "share", "pictures")
+        self.set_test_content_hub(self.default_appname, "source", "pictures")
+        c = ClickReviewContentHub(self.test_name)
+        c.check_valid()
+        r = c.click_report
+        # should be empty with this pkgfmt
+        expected_counts = {'info': 0, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
